aboutsummaryrefslogtreecommitdiffstats
path: root/src/mds-kbdc/tree.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/mds-kbdc/tree.h')
-rw-r--r--src/mds-kbdc/tree.h14
1 files changed, 8 insertions, 6 deletions
diff --git a/src/mds-kbdc/tree.h b/src/mds-kbdc/tree.h
index d12adea..e529dfc 100644
--- a/src/mds-kbdc/tree.h
+++ b/src/mds-kbdc/tree.h
@@ -170,18 +170,20 @@ typedef union mds_kbdc_tree mds_kbdc_tree_t;
* tree structures.
*
* It defines:
* - int type; -- Integer that specifies which structure is used
* - mds_kbdc_tree_t*; -- The next node in the tree, at the same level; a sibling
* - loc_line; -- The line in the source code where this is found
* - loc_start; -- The first byte in the source code where this is found, inclusive
* - loc_end; -- The last byte in the source code where this is found, exclusive
*/
#define MDS_KBDC_TREE_COMMON \
int type; \
mds_kbdc_tree_t* next; \
size_t loc_line; \
size_t loc_start; \
- size_t loc_end
+ size_t loc_end; \
+ long processed
/**
* This macro is used in this header file, and is then
@@ -170,18 +170,20 @@ typedef union mds_kbdc_tree mds_kbdc_tree_t;
*
* It defines:
- * - int type; -- Integer that specifies which structure is used
- * - mds_kbdc_tree_t*; -- The next node in the tree, at the same level; a sibling
- * - loc_line; -- The line in the source code where this is found
- * - loc_start; -- The first byte in the source code where this is found, inclusive
- * - loc_end; -- The last byte in the source code where this is found, exclusive
+ * - int type; -- Integer that specifies which structure is used
+ * - mds_kbdc_tree_t* next; -- The next node in the tree, at the same level; a sibling
+ * - size_t loc_line; -- The line in the source code where this is found
+ * - size_t loc_start; -- The first byte in the source code where this is found, inclusive
+ * - size_t loc_end; -- The last byte in the source code where this is found, exclusive
+ * - long processed; -- The lasted step where the statement has already been processed once
*/
#define MDS_KBDC_TREE_COMMON \